diff --git a/src/ptbench/data/nih_cxr14/datamodule.py b/src/ptbench/data/nih_cxr14/datamodule.py
index 09115de8fe4cebd7e5a83fec10fee5d776ab5daf..5452640949ecc998ea4ee026616a894b1a7be7e9 100644
--- a/src/ptbench/data/nih_cxr14/datamodule.py
+++ b/src/ptbench/data/nih_cxr14/datamodule.py
@@ -29,7 +29,7 @@ class RawDataLoader(_BaseRawDataLoader):
 
     idiap_file_organisation
         This variable will be ``True``, if the user has set the configuration
         parameter ``nih_cxr14_re.idiap_file_organisation`` in the global
         configuration file.  It will cause internal loader to search for files
         in a slightly different folder structure, that was adapted to Idiap's
         requirements (number of files per folder to be less than 10k).
@@ -40,11 +40,9 @@ class RawDataLoader(_BaseRawDataLoader):
 
     def __init__(self):
         rc = load_rc()
-        self.datadir = rc.get(
-            "datadir.nih_cxr14_re", os.path.realpath(os.curdir)
-        )
+        self.datadir = rc.get("datadir.nih_cxr14", os.path.realpath(os.curdir))
         self.idiap_file_organisation = rc.get(
-            "nih_cxr14_re.idiap_folder_structure", False
+            "nih_cxr14.idiap_folder_structure", False
         )
 
     def sample(self, sample: tuple[str, list[int]]) -> Sample:
@@ -29,7 +29,7 @@ class RawDataLoader(_BaseRawDataLoader):
     idiap_file_organisation
         This variable will be ``True``, if the user has set the configuration
-        parameter ``nih_cxr14_re.idiap_file_organisation`` in the global
+        parameter ``nih_cxr14.idiap_file_organisation`` in the global
         configuration file.  It will cause internal loader to search for files
         in a slightly different folder structure, that was adapted to Idiap's